@@ -1,4 +1,4 @@
-from netqasm.sdk.epr_socket import EPRMeasBasis, EPRSocket, EPRType
+from netqasm.sdk.epr_socket import EPRMeasBasis, EPRSocket
 from netqasm.sdk.external import NetQASMConnection
 
 
@@ -17,9 +17,8 @@ def main(app_config=None):
     num_pairs = 10
 
     with client:
-        outcomes = epr_socket.create(
+        outcomes = epr_socket.create_measure(
             number=num_pairs,
-            tp=EPRType.M,
             basis_local=EPRMeasBasis.Y,
             basis_remote=EPRMeasBasis.Y,
         )
